@@ -1,5 +1,5 @@
 from functools import wraps
-from flask import Blueprint, request, abort
+from flask import Blueprint, request
 from simple_websocket import Server, ConnectionClosed
 
 
@@ -21,10 +21,15 @@ class Sock:
         def decorator(f):
             @wraps(f)
             def websocket_route(*args, **kwargs):
+                ws = Server(request.environ)
                 try:
-                    f(Server(request.environ), *args, **kwargs)
+                    f(ws, *args, **kwargs)
                 except ConnectionClosed:
                     pass
+                try:
+                    ws.close()
+                except:  # noqa: E722
+                    pass
                 return ''
 
             kwargs['websocket'] = True
